# Copyright The OpenTelemetry Authors
# SPDX-License-Identifier: Apache-2.0

from typing import Final

URL_FRAGMENT: Final = "url.fragment"
"""
The [URI fragment](https://www.rfc-editor.org/rfc/rfc3986#section-3.5) component.
"""

URL_FULL: Final = "url.full"
"""
Absolute URL describing a network resource according to [RFC3986](https://www.rfc-editor.org/rfc/rfc3986).
Note: For network calls, URL usually has `scheme://host[:port][path][?query][#fragment]` format, where the fragment
is not transmitted over HTTP, but if it is known, it SHOULD be included nevertheless.

`url.full` MUST NOT contain credentials passed via URL in form of `https://username:password@www.example.com/`.
In such case username and password SHOULD be redacted and attribute's value SHOULD be `https://REDACTED:REDACTED@www.example.com/`.

`url.full` SHOULD capture the absolute URL when it is available (or can be reconstructed).

Sensitive content provided in `url.full` SHOULD be scrubbed when instrumentations can identify it.

![Development](https://img.shields.io/badge/-development-blue)
Query string values for the following keys SHOULD be redacted by default and replaced by the
value `REDACTED`:

* [`X-Amz-Signature`](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_sigv-authentication-methods.html)
* [`X-Amz-Credential`](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_sigv-authentication-methods.html)
* [`X-Amz-Security-Token`](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_sigv-authentication-methods.html)
* [`sig`](https://learn.microsoft.com/azure/storage/common/storage-sas-overview#sas-token)
* [`X-Goog-Signature`](https://cloud.google.com/storage/docs/access-control/signed-urls)

This list is subject to change over time.

Matching of query parameter keys against the sensitive list SHOULD be case-sensitive.

![Development](https://img.shields.io/badge/-development-blue)
Instrumentation MAY provide a way to override this list via declarative configuration.
If so, it SHOULD use the `sensitive_query_parameters` property
(an array of case-sensitive strings with minimum items 0) under
`.instrumentation/development.general.sanitization.url`.
This list is a full override of the default sensitive query parameter keys,
it is not a list of keys in addition to the defaults.

When a query string value is redacted, the query string key SHOULD still be preserved, e.g.
`https://www.example.com/path?color=blue&sig=REDACTED`.
"""

URL_PATH: Final = "url.path"
"""
The [URI path](https://www.rfc-editor.org/rfc/rfc3986#section-3.3) component.
Note: Sensitive content provided in `url.path` SHOULD be scrubbed when instrumentations can identify it.
"""

URL_QUERY: Final = "url.query"
"""
The [URI query](https://www.rfc-editor.org/rfc/rfc3986#section-3.4) component.
Note: Sensitive content provided in `url.query` SHOULD be scrubbed when instrumentations can identify it.

![Development](https://img.shields.io/badge/-development-blue)
Query string values for the following keys SHOULD be redacted by default and replaced by the value `REDACTED`:

* [`X-Amz-Signature`](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_sigv-authentication-methods.html)
* [`X-Amz-Credential`](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_sigv-authentication-methods.html)
* [`X-Amz-Security-Token`](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_sigv-authentication-methods.html)
* [`sig`](https://learn.microsoft.com/azure/storage/common/storage-sas-overview#sas-token)
* [`X-Goog-Signature`](https://cloud.google.com/storage/docs/access-control/signed-urls)

This list is subject to change over time.

Matching of query parameter keys against the sensitive list SHOULD be case-sensitive.

Instrumentation MAY provide a way to override this list via declarative configuration.
If so, it SHOULD use the `sensitive_query_parameters` property
(an array of case-sensitive strings with minimum items 0) under
`.instrumentation/development.general.sanitization.url`.
This list is a full override of the default sensitive query parameter keys,
it is not a list of keys in addition to the defaults.

When a query string value is redacted, the query string key SHOULD still be preserved, e.g.
`q=OpenTelemetry&sig=REDACTED`.
"""

URL_SCHEME: Final = "url.scheme"
"""
The [URI scheme](https://www.rfc-editor.org/rfc/rfc3986#section-3.1) component identifying the used protocol.
"""



# Copyright The OpenTelemetry Authors
# SPDX-License-Identifier: Apache-2.0

from enum import Enum
from typing import Final

ERROR_TYPE: Final = "error.type"
"""
Describes a class of error the operation ended with.
Note: The `error.type` SHOULD be predictable, and SHOULD have low cardinality.

When `error.type` is set to a type (e.g., an exception type), its
canonical class name identifying the type within the artifact SHOULD be used.

If the recorded error type is a wrapper that is not meaningful for
failure classification, instrumentation MAY use the type of the inner
error instead. For example, in Go, errors created with `fmt.Errorf`
using `%w` MAY be unwrapped when the wrapper type does not help
classify the failure.

Instrumentations SHOULD document the list of errors they report.

The cardinality of `error.type` within one instrumentation library SHOULD be low.
Telemetry consumers that aggregate data from multiple instrumentation libraries and applications
should be prepared for `error.type` to have high cardinality at query time when no
additional filters are applied.

If the operation has completed successfully, instrumentations SHOULD NOT set `error.type`.

If a specific domain defines its own set of error identifiers (such as HTTP or RPC status codes),
it's RECOMMENDED to:

- Use a domain-specific attribute
- Set `error.type` to capture all errors, regardless of whether they are defined within the domain-specific set or not.
"""


class ErrorTypeValues(Enum):
    OTHER = "_OTHER"
    """A fallback error value to be used when the instrumentation doesn't define a custom value."""



# Copyright The OpenTelemetry Authors
# SPDX-License-Identifier: Apache-2.0

from typing import Final

ZOS_SMF_ID: Final = "zos.smf.id"
"""
The System Management Facility (SMF) Identifier uniquely identified a z/OS system within a SYSPLEX or mainframe environment and is used for system and performance analysis.
"""

ZOS_SYSPLEX_NAME: Final = "zos.sysplex.name"
"""
The name of the SYSPLEX to which the z/OS system belongs too.
"""



# Copyright The OpenTelemetry Authors
# SPDX-License-Identifier: Apache-2.0

from enum import Enum
from typing import Final

from typing_extensions import deprecated

MCP_METHOD_NAME: Final = "mcp.method.name"
"""
Deprecated: Moved to the [OpenTelemetry GenAI semantic conventions repository](https://github.com/open-telemetry/semantic-conventions-genai).
"""

MCP_PROTOCOL_VERSION: Final = "mcp.protocol.version"
"""
Deprecated: Moved to the [OpenTelemetry GenAI semantic conventions repository](https://github.com/open-telemetry/semantic-conventions-genai).
"""

MCP_RESOURCE_URI: Final = "mcp.resource.uri"
"""
Deprecated: Moved to the [OpenTelemetry GenAI semantic conventions repository](https://github.com/open-telemetry/semantic-conventions-genai).
"""

MCP_SESSION_ID: Final = "mcp.session.id"
"""
Deprecated: Moved to the [OpenTelemetry GenAI semantic conventions repository](https://github.com/open-telemetry/semantic-conventions-genai).
"""


@deprecated(
    "The attribute mcp.method.name is deprecated - Moved to the [OpenTelemetry GenAI semantic conventions repository](https://github.com/open-telemetry/semantic-conventions-genai)"
)
class McpMethodNameValues(Enum):
    NOTIFICATIONS_CANCELLED = "notifications/cancelled"
    """Notification cancelling a previously-issued request."""
    INITIALIZE = "initialize"
    """Request to initialize the MCP client."""
    NOTIFICATIONS_INITIALIZED = "notifications/initialized"
    """Notification indicating that the MCP client has been initialized."""
    NOTIFICATIONS_PROGRESS = "notifications/progress"
    """Notification indicating the progress for a long-running operation."""
    PING = "ping"
    """Request to check that the other party is still alive."""
    RESOURCES_LIST = "resources/list"
    """Request to list resources available on server."""
    RESOURCES_TEMPLATES_LIST = "resources/templates/list"
    """Request to list resource templates available on server."""
    RESOURCES_READ = "resources/read"
    """Request to read a resource."""
    NOTIFICATIONS_RESOURCES_LIST_CHANGED = (
        "notifications/resources/list_changed"
    )
    """Notification indicating that the list of resources has changed."""
    RESOURCES_SUBSCRIBE = "resources/subscribe"
    """Request to subscribe to a resource."""
    RESOURCES_UNSUBSCRIBE = "resources/unsubscribe"
    """Request to unsubscribe from resource updates."""
    NOTIFICATIONS_RESOURCES_UPDATED = "notifications/resources/updated"
    """Notification indicating that a resource has been updated."""
    PROMPTS_LIST = "prompts/list"
    """Request to list prompts available on server."""
    PROMPTS_GET = "prompts/get"
    """Request to get a prompt."""
    NOTIFICATIONS_PROMPTS_LIST_CHANGED = "notifications/prompts/list_changed"
    """Notification indicating that the list of prompts has changed."""
    TOOLS_LIST = "tools/list"
    """Request to list tools available on server."""
    TOOLS_CALL = "tools/call"
    """Request to call a tool."""
    NOTIFICATIONS_TOOLS_LIST_CHANGED = "notifications/tools/list_changed"
    """Notification indicating that the list of tools has changed."""
    LOGGING_SET_LEVEL = "logging/setLevel"
    """Request to set the logging level."""
    NOTIFICATIONS_MESSAGE = "notifications/message"
    """Notification indicating that a message has been received."""
    SAMPLING_CREATE_MESSAGE = "sampling/createMessage"
    """Request to create a sampling message."""
    COMPLETION_COMPLETE = "completion/complete"
    """Request to complete a prompt."""
    ROOTS_LIST = "roots/list"
    """Request to list roots available on server."""
    NOTIFICATIONS_ROOTS_LIST_CHANGED = "notifications/roots/list_changed"
    """Notification indicating that the list of roots has changed."""
    ELICITATION_CREATE = "elicitation/create"
    """Request from the server to elicit additional information from the user via the client."""
